apc.indiv.ftest.fullapc <- function(data,  big.model="APC", 
                                    small.model, dep.var, covariates=NULL,
                                    model.family="gaussian", unit=1, 
                                    n.coh.excl.start=0, n.coh.excl.end=0,
                                    n.age.excl.start=0, n.age.excl.end=0,
                                    n.per.excl.start=0, n.per.excl.end=0,
                                    existing.big.model.fit=NULL, 
                                    existing.small.model.fit=NULL,
                                    existing.collinear=NULL){
  ######################	
  # This functions runs an F-test comparing the fit of a single 
  # APC submodel to the full APC model.
  ######################	
  # Step 1: Fit reduced APC model (the submodel)
  
  if(is.null(existing.small.model.fit)){
    if(is.null(existing.collinear)){
      collinear.R <- apc.indiv.design.collinear(data, 
                                                unit = unit,
                                                n.coh.excl.start = n.coh.excl.start,
                                                n.coh.excl.end = n.coh.excl.end,
                                                n.age.excl.start = n.age.excl.start,
                                                n.age.excl.end = n.age.excl.end,
                                                n.per.excl.start = n.per.excl.start,
                                                n.per.excl.end = n.per.excl.end)
    } else
      collinear.R <- existing.collinear
    design.R <- apc.indiv.design.model(apc.indiv.design.collinear =collinear.R, 
                                       model.design = small.model,
                                       dep.var=dep.var,
                                       covariates=covariates)
    fitted.R <- apc.indiv.fit.model(design.R, model.family=model.family)
  } else 
    fitted.R <- existing.small.model.fit
  
  # Get RSS, number of parameters
  RSS.APC.R <- sum(fitted.R$residuals^2)
  nparam.APC.R <- length(fitted.R$coefficients)
  ######################	
  # Step 2: Fit full APC model
  if(is.null(existing.big.model.fit)){
    # note: can use same collinear design matrix for full model as for submodel
    design.U <- apc.indiv.design.model(apc.indiv.design.collinear =collinear.R, 
                                       model.design = big.model, 
                                       dep.var=dep.var,
                                       covariates=covariates)
    fitted.U <- apc.indiv.fit.model(design.U, model.family=model.family)
  } else 
    fitted.U <- existing.big.model.fit
  
  # Get RSS, number of parameters, number of observations
  RSS.APC.U <- sum(fitted.U$residuals^2)
  nparam.APC.U <- length(fitted.U$coefficients)
  sample.N.APC.U <- length(fitted.U$y)
  ######################	
  # Step 3: Run F-test
  
  # Get elements of F-test
  big.model.RSS <- RSS.APC.U
  small.model.RSS <- RSS.APC.R
  big.model.nparams <- nparam.APC.U
  small.model.nparams <- nparam.APC.R
  sample.N <- sample.N.APC.U
  
  df.num <- big.model.nparams - small.model.nparams
  df.denom <- sample.N - big.model.nparams
  df <- paste("(", paste(as.character(df.num), as.character(df.denom), 
                         sep=", "), ")", sep="")
  
  # Construct F-statistic
  fstat.num <- (small.model.RSS - big.model.RSS)/df.num
  fstat.denom <- (big.model.RSS - 0)/df.denom
  fstat <- fstat.num/fstat.denom
  
  # Get p-value by comparing F-statistic to F-distribution
  p.value <- pf(fstat, df1 = df.num, df2 = df.denom, lower.tail = FALSE)
  ######################	
  # valuables
  valuables <- list(fstat = fstat,
                    df = df,
                    df.num = df.num,
                    df.denom = df.denom,
                    p.value = p.value,
                    aic.big = fitted.U$aic,
                    aic.small = fitted.R$aic,
                    lik.big = fitted.U$likelihood,
                    lik.small = fitted.R$likelihood)
  
  return(valuables)
}